.. currentmodule:: pydemic.models

Reference: Models
=================

.. automodule:: pydemic.models


Other utilities for modeling
----------------------------

.. automodule:: pydemic.distributions

.. automodule:: pydemic.mitigation
